<?php

namespace Drupal\oembed_lazyload_youtube\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Settings form for the oembed lazyload youtube module.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['oembed_lazyload_youtube.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'oembed_lazyload_youtube_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['resource_fetcher_thumbnail_strategy'] = [
      '#type' => 'radios',
      '#title' => $this->t('Resource fetcher thumbnail strategy'),
      '#options' => [
        'default' => $this->t('Default'),
        'prefer_max_resolution' => $this->t('Prefer maximum image resolution'),
      ],
      '#default_value' => $this->config('oembed_lazyload_youtube.settings')->get('resource_fetcher_thumbnail_strategy'),
    ];

    if (!$this->config('oembed_lazyload.settings')->get('enable_resource_fetcher_overrides')) {
      $this->messenger()->addWarning('Resource fetching overrides are not enabled. Some settings will have no effect here.');
      $form['resource_fetcher_thumbnail_strategy']['#disabled'] = TRUE;
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('oembed_lazyload_youtube.settings')
      ->set('resource_fetcher_thumbnail_strategy', $form_state->getValue('resource_fetcher_thumbnail_strategy'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
