<?php

namespace Drupal\Tests\oembed_lazyload_youtube\Functional;

use Drupal\FunctionalTests\Update\UpdatePathTestBase;

/**
 * Test cases for upgrade paths.
 *
 * @group oembed_lazyload_youtubex
 */
class FlexiblePlaceholdersUpdateTest extends UpdatePathTestBase {

  /**
   * The config factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->configFactory = $this->container->get('config.factory');
  }

  /**
   * Gets an uncached copy of the module config.
   *
   * @return \Drupal\Core\Config\ImmutableConfig
   *   The module config.
   */
  protected function getModuleConfig() {
    $this->configFactory->clearStaticCache();
    return $this->configFactory->get('oembed_lazyload_youtube.settings');
  }

  /**
   * {@inheritdoc}
   */
  protected function setDatabaseDumpFiles() {
    $this->databaseDumpFiles = [
      static::getDrupalRoot() . '/core/modules/system/tests/fixtures/update/drupal-9.4.0.bare.standard.php.gz',
      __DIR__ . '/../../fixtures/oembed_lazyload_youtube.update-hook-test.php',
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function doSelectionTest() {
    parent::doSelectionTest();
    $this->assertSession()->responseContains('Set default resource fetching strategy configuration.');
  }

  /**
   * Test case for when configuration is an expected state.
   */
  public function testPostUpdateResourceFetcherStrategy() {
    static::assertNull($this->getModuleConfig()->get('resource_fetcher_thumbnail_strategy'));
    $this->runUpdates();

    static::assertEquals(
      'default',
      $this->getModuleConfig()->get('resource_fetcher_thumbnail_strategy')
    );
  }

  /**
   * Test case for when configuration is an unexpected state.
   */
  public function testPostUpdateResourceFetcherStrategyUncommonScenario() {
    $this->configFactory->getEditable('oembed_lazyload_youtube.settings')
      ->set('resource_fetcher_thumbnail_strategy', 'prefer_max_resolution')
      ->save();
    $this->runUpdates();

    // The update hook should not modify data that somehow already exists.
    static::assertEquals(
      'prefer_max_resolution',
      $this->getModuleConfig()->get('resource_fetcher_thumbnail_strategy')
    );
  }

}
