<?php

namespace Drupal\Tests\oembed_lazyload_youtube\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Test cases pertaining to the oembed lazyload YouTube settings form.
 *
 * @group oembed_lazyload_youtube
 */
class OEmbedLazyloadYoutubeSettingsFormTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'oembed_lazyload',
    'oembed_lazyload_youtube',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Test case for the settings form.
   */
  public function testSettingsForm() {
    $assert = $this->assertSession();

    // Access denied if the user doesn't have permission.
    $this->drupalGet('/admin/config/media/oembed-lazyload/youtube');
    $assert->statusCodeEquals(403);

    // Access granted if the user does have permission.
    $this->drupalLogin($this->drupalCreateUser(['administer site configuration']));
    $this->drupalGet('/admin/config/media/oembed-lazyload/youtube');
    $assert->statusCodeEquals(200);

    // Ensure we get a warning rendered by default.
    $assert->pageTextContainsOnce('Resource fetching overrides are not enabled. Some settings will have no effect here.');

    // Ensure the proper controls are disabled by default.
    $assert->fieldDisabled('Prefer maximum image resolution');

    // Turn on resource fetcher customizations.
    $this->drupalGet('/admin/config/media/oembed-lazyload');
    $this->getSession()->getPage()->checkField('Enable advanced resource fetching controls');
    $this->submitForm([], 'Save configuration');

    $this->drupalGet('/admin/config/media/oembed-lazyload/youtube');

    // Ensure the warning goes away.
    $assert->pageTextNotContains('Resource fetching overrides are not enabled. Some settings will have no effect here.');

    // Ensure the proper state with resource fetching enabled.
    $assert->fieldValueEquals('resource_fetcher_thumbnail_strategy', 'default');

    // Ensure the proper state in active config.
    static::assertSame(
      'default',
      $this->config('oembed_lazyload_youtube.settings')->get('resource_fetcher_thumbnail_strategy')
    );

    // Toggle the field value and save.
    $this->submitForm(['resource_fetcher_thumbnail_strategy' => 'prefer_max_resolution'], 'Save configuration');

    // Ensure the proper state has persisted in the form.
    $assert->fieldValueEquals('resource_fetcher_thumbnail_strategy', 'prefer_max_resolution');

    // Ensure the proper state has persisted in active config.
    static::assertSame(
      'prefer_max_resolution',
      $this->config('oembed_lazyload_youtube.settings')->get('resource_fetcher_thumbnail_strategy')
    );
  }

}
