<?php

/**
 * Set default resource fetching overrides and field formatter configuration.
 */
function oembed_lazyload_post_update_flexible_placeholder_config() {
  $config = \Drupal::configFactory()->getEditable('oembed_lazyload.settings');

  // If a setting somehow already exists, don't replace the value.
  if (!array_key_exists('enable_resource_fetcher_overrides', $config->getRawData())) {
    $config
      ->set('enable_resource_fetcher_overrides', FALSE)
      ->save();
  }

  $new_settings = [
    'dimensions' => 'legacy',
    'placeholder_loading' => 'lazy',
    'placeholder_asset_type' => 'remote_asset',
    'placeholder_local_asset_image_style_type' => \Drupal::moduleHandler()->moduleExists('responsive_image') ? 'responsive_image_style' : 'image_style',
    'placeholder_local_asset_responsive_image_style' => '',
    'placeholder_local_asset_image_style' => '',
  ];

  /** @var \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager */
  $entity_type_manager = \Drupal::service('entity_type.manager');

  /** @var array|\Drupal\Core\Entity\Display\EntityViewDisplayInterface[] $entity_displays */
  $entity_displays = $entity_type_manager->getStorage('entity_view_display')->loadMultiple();

  // Iterate over all components of all displays.
  foreach ($entity_displays as $entity_display) {
    foreach ($entity_display->getComponents() as $field_name => $component) {

      // Make sure we're operating on the correct formatter type.
      if (array_key_exists('type', $component) && $component['type'] === 'lazyload_oembed') {

        // Apply the proper default settings.
        foreach ($new_settings as $setting => $default_value) {

          // If a setting somehow already exists, don't replace the value.
          if (!array_key_exists($setting, $component['settings'])) {
            $component['settings'][$setting] = $default_value;
          }
        }

        $entity_display
          ->setComponent($field_name, $component)
          ->save();
      }
    }
  }
}
