<?php

namespace Drupal\oembed_lazyload\Oembed;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\media\OEmbed\ResourceFetcher;
use Drupal\oembed_lazyload\ProviderEnhancerManagerInterface;

/**
 * Gives provider enhancers a chance to alter oembed metadata.
 */
class OembedLazyloadResourceFetcher extends ResourceFetcher {

  /**
   * The config factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The OEmbed lazyload manager service.
   *
   * @var \Drupal\oembed_lazyload\ProviderEnhancerManager
   */
  protected $providerEnhancerManager;

  /**
   * Invoked by the service container.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory service.
   *
   * @see \Drupal\oembed_lazyload\OembedLazyloadServiceProvider::alter()
   */
  public function setConfigFactory(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * Invoked by the service container.
   *
   * @param \Drupal\oembed_lazyload\ProviderEnhancerManagerInterface $provider_enhancer_manager
   *   The provider enhancer manager service.
   *
   * @see \Drupal\oembed_lazyload\OembedLazyloadServiceProvider::alter()
   */
  public function setProviderEnhancerManager(ProviderEnhancerManagerInterface $provider_enhancer_manager) {
    $this->providerEnhancerManager = $provider_enhancer_manager;
  }

  /**
   * {@inheritdoc}
   */
  protected function createResource(array $data, $url) {
    $config = $this->configFactory->get('oembed_lazyload.settings');
    if ($config->get('enable_resource_fetcher_overrides')) {
      $this->providerEnhancerManager
        ->getEnhancerForProvider($data['provider_name'])
        ->alterOembedMetadata($data, $url);
    }

    return parent::createResource($data, $url);
  }

}
