<?php

namespace Drupal\Tests\oembed_lazyload\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Test cases pertaining to the oembed lazyload settings form.
 *
 * @group oembed_lazyload
 */
class OEmbedLazyloadSettingsFormTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'oembed_lazyload',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Test case for the settings form.
   */
  public function testSettingsForm() {
    $assert = $this->assertSession();

    // Access denied if the user doesn't have permission.
    $this->drupalGet('/admin/config/media/oembed-lazyload');
    $assert->statusCodeEquals(403);

    // Access granted if the user does have permission.
    $this->drupalLogin($this->drupalCreateUser(['administer site configuration']));
    $this->drupalGet('/admin/config/media/oembed-lazyload');
    $assert->statusCodeEquals(200);

    // Check the default configuration state in the form.
    $assert->checkboxNotChecked('Enable advanced resource fetching controls');

    // Check the default configuration state in active storage.
    static::assertFalse(
      $this->config('oembed_lazyload.settings')
        ->get('enable_resource_fetcher_overrides')
    );

    // Toggle the field value and save.
    $this->getSession()->getPage()->checkField('Enable advanced resource fetching controls');
    $this->submitForm([], 'Save configuration');

    // Ensure state has persisted in the form.
    $assert->checkboxChecked('Enable advanced resource fetching controls');

    // Ensure state has persisted in active storage.
    static::assertTrue(
      $this->config('oembed_lazyload.settings')
        ->get('enable_resource_fetcher_overrides')
    );
  }

}
